Module editor
vimltui
0.1.9
Module editor
Module Items
Modules
Structs
In crate vimltui
vimltui
Module
editor
Modules

input
motions
operators
search
visual
Structs

VimEditor
A self-contained Vim editor instance with its own buffer, cursor, mode, and state. Each view that needs a Vim editor creates its own VimEditor.