pub struct Diagnostic {
pub severity: DiagnosticSeverity,
pub message: Option<String>,
}Expand description
A diagnostic for a specific line, rendered to the LEFT of the line number.
Consumers populate GutterConfig::diagnostics with these values.
When non-empty, the gutter reserves 2 extra characters for the diagnostic
column ([icon][space]). When empty, no extra space is used.
When the cursor is on a line with a diagnostic that has a message,
the message is shown in the command line.
Fields
severity: DiagnosticSeveritySeverity level (determines icon and color).
message: Option<String>Optional message shown in the command line when the cursor is on this line.